vitriolic
=========

This project unifies the various sub-projects Touch Technology has created over
the years that were intended to be reusable in isolation, but in practice never
stood alone for long. The maintenance burden has become too great.

Origin of the name
------------------

I decided to do this on Tuesday 8th November, US Election day 2016. The
`wiktionary word of the day`_ was vitriolic which, given the nature of Donald
Trump's campaign to become American President, it seemed like a pretty good
fit.

.. raw:: html

   <s>

As at time of authoring this document I have no idea if he'll win the election.

.. raw:: html

   </s>

This project will now forever remind me of the day that America shat the bed.

Former band members
-------------------

The following modules are to be incorporated.

-  touchtechnology.public
-  `touchtechnology.common <https://bitbucket.org/touchtechnology/common>`__
-  `touchtechnology.admin <https://bitbucket.org/touchtechnology/admin>`__
-  `touchtechnology.content <https://bitbucket.org/touchtechnology/content>`__
-  `touchtechnology.news <https://bitbucket.org/touchtechnology/news>`__
-  `tournamentcontrol.competition <https://bitbucket.org/tournamentcontrol/competition>`__
-  shuriken

Badges
------

Got to have badges!

|PyPi Version| |Build Status| |Coverage Status|

.. |PyPi Version| image:: https://img.shields.io/pypi/v/vitriolic.svg
   :target: https://pypi.python.org/pypi/vitriolic
.. |Build Status| image:: https://travis-ci.org/goodtune/vitriolic.svg?branch=master
   :target: https://travis-ci.org/goodtune/vitriolic
.. |Coverage Status| image:: https://coveralls.io/repos/github/goodtune/vitriolic/badge.svg?branch=master
   :target: https://coveralls.io/github/goodtune/vitriolic?branch=master

.. _`wiktionary word of the day`: https://en.wiktionary.org/wiki/Wiktionary:Word_of_the_day
